@@ -23,11 +23,14 @@
 #define Rcpp_DottedPair_h
 
 #include <RcppCommon.h>
+#include <Rcpp/exceptions.h>
 
 #include <Rcpp/Symbol.h>
 #include <Rcpp/grow.h>
 #include <Rcpp/Named.h>
 
+#include <Rcpp/RObject.h>
+
 namespace Rcpp{ 
 
 class DottedPair : public RObject{
